@@ -49,7 +49,8 @@ bjb_empty_results_box_constructed (GObject *object)
   BjbEmptyResultsBoxPrivate *priv;
   GtkStyleContext *context;
   GtkWidget *labels_grid;
-  gchar *label, *markup;
+  const gchar *label;
+  gchar *markup;
   GFile *note_icon_file;
   GIcon *icon;
 
@@ -161,6 +162,7 @@ bjb_empty_results_box_set_type (BjbEmptyResultsBox *self,
       gtk_widget_show (self->priv->image);
       break;
 
+    case BJB_EMPTY_RESULTS_TYPE:
     default:
       break;
   }
