@@ -256,21 +256,12 @@ bjb_window_base_constructed (GObject *obj)
   const gint32 *size;
   gsize n_elements;
   GVariant *variant;
-  GdkVisual *rgba_visual;
 
   G_OBJECT_CLASS (bjb_window_base_parent_class)->constructed (obj);
 
   priv = self->priv;
   priv->settings = bjb_app_get_settings ((gpointer) g_application_get_default ());
 
-  /* Allow transparencies if possible */
-  rgba_visual = gdk_screen_get_rgba_visual (gtk_window_get_screen (GTK_WINDOW (self)));
-  if (rgba_visual)
-  {
-    gtk_widget_set_visual (GTK_WIDGET (self), rgba_visual);
-    gtk_widget_set_app_paintable (GTK_WIDGET (self), TRUE);
-  }
-
   gtk_window_set_position (GTK_WINDOW (self),GTK_WIN_POS_CENTER);
   gtk_window_set_title (GTK_WINDOW (self), _(BIJIBEN_MAIN_WIN_TITLE));
 
@@ -481,11 +472,13 @@ void
 bjb_window_base_switch_to (BjbWindowBase *self, BjbWindowViewType type)
 {
   BjbWindowBasePriv *priv = self->priv;
-  priv->current_view = type;
 
   if (type != BJB_WINDOW_BASE_NOTE_VIEW)
     destroy_note_if_needed (self);
 
+  if (priv->current_view == BJB_WINDOW_BASE_ARCHIVE_VIEW && type == BJB_WINDOW_BASE_NO_NOTE)
+    type = priv->current_view;
+
   switch (type)
   {
 
@@ -553,6 +546,8 @@ bjb_window_base_switch_to (BjbWindowBase *self, BjbWindowViewType type)
       return;
   }
 
+  priv->current_view = type;
+
   g_signal_emit (G_OBJECT (self), bjb_win_base_signals[BJB_WIN_BASE_VIEW_CHANGED],0);
 }
 
