@@ -86,6 +86,9 @@ static guint biji_obj_signals [BIJI_OBJ_SIGNALS] = { 0 };
 
 G_DEFINE_TYPE (BijiNoteObj, biji_note_obj, BIJI_TYPE_ITEM);
 
+gboolean is_webkit1 (const char *content);
+gchar * convert_webkit1_to_webkit2 (const gchar *content);
+
 static void
 on_save_timeout (BijiNoteObj *self)
 {
@@ -234,7 +237,7 @@ biji_note_obj_are_same (BijiNoteObj *a, BijiNoteObj* b)
 
 /* First cancel timeout
  * this func is most probably stupid it might exists (move file) */
-gboolean
+static gboolean
 biji_note_obj_trash (BijiItem *item)
 {
   BijiNoteObj *note_to_kill;
@@ -287,21 +290,15 @@ biji_note_obj_is_trashed                    (BijiNoteObj *self)
 static const gchar *
 biji_note_obj_get_path (BijiItem *item)
 {
+  BijiNoteObj *note;
+
   g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), NULL);
 
-  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
+  note = BIJI_NOTE_OBJ (item);
 
   return biji_note_id_get_path (note->priv->id);
 }
 
-
-BijiNoteID *
-note_get_id(BijiNoteObj* n)
-{
-  return n->priv->id;
-}
-
-
 static const gchar *
 biji_note_obj_get_title (BijiItem *note)
 {
@@ -367,7 +364,7 @@ biji_note_obj_get_mtime (BijiItem *note)
   return biji_note_id_get_mtime (BIJI_NOTE_OBJ (note)->priv->id);
 }
 
-gchar *
+const gchar *
 biji_note_obj_get_last_change_date_string (BijiNoteObj *self)
 {
   g_return_val_if_fail (BIJI_IS_NOTE_OBJ (self), "");
@@ -394,14 +391,6 @@ biji_note_obj_set_last_metadata_change_date (BijiNoteObj* n, gint64 time)
   return biji_note_id_set_last_metadata_change_date (n->priv->id, time);
 }
 
-gboolean
-biji_note_obj_set_note_create_date (BijiNoteObj* n, gint64 time)
-{
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ(n), FALSE);
-
-  return biji_note_id_set_create_date (n->priv->id, time);
-}
-
 static void
 biji_note_obj_clear_icons (BijiNoteObj *note)
 {
@@ -411,7 +400,8 @@ biji_note_obj_clear_icons (BijiNoteObj *note)
 }
 
 static void
-biji_note_obj_set_rgba_internal (BijiNoteObj *n, GdkRGBA *rgba)
+biji_note_obj_set_rgba_internal (BijiNoteObj *n,
+                                 const GdkRGBA *rgba)
 {
   n->priv->color = gdk_rgba_copy(rgba);
 
@@ -419,7 +409,8 @@ biji_note_obj_set_rgba_internal (BijiNoteObj *n, GdkRGBA *rgba)
 }
 
 void
-biji_note_obj_set_rgba (BijiNoteObj *n, GdkRGBA *rgba)
+biji_note_obj_set_rgba (BijiNoteObj *n,
+                        const GdkRGBA *rgba)
 {
   if (!n->priv->color)
     biji_note_obj_set_rgba_internal (n, rgba);
@@ -458,7 +449,8 @@ biji_note_obj_get_raw_text                  (BijiNoteObj *note)
 }
 
 void
-biji_note_obj_set_raw_text (BijiNoteObj *note, gchar *plain_text)
+biji_note_obj_set_raw_text (BijiNoteObj *note,
+                            const gchar *plain_text)
 {
   if (biji_note_id_set_content (note->priv->id, plain_text))
   {
@@ -475,7 +467,7 @@ biji_note_obj_get_notebooks (BijiNoteObj *n)
   return g_hash_table_get_values (n->priv->labels);
 }
 
-gboolean
+static gboolean
 biji_note_obj_has_notebook (BijiItem *item, gchar *label)
 {
   BijiNoteObj *note = BIJI_NOTE_OBJ (item);
@@ -498,7 +490,7 @@ _biji_notebook_refresh (gboolean query_result,
 }
 
 
-/*static */ gboolean
+static gboolean
 biji_note_obj_add_notebook (BijiItem *item,
                               BijiItem *notebook,
                               gchar    *title)
@@ -530,13 +522,15 @@ biji_note_obj_add_notebook (BijiItem *item,
 }
 
 
-gboolean
+static gboolean
 biji_note_obj_remove_notebook (BijiItem *item, BijiItem *notebook)
 {
+  BijiNoteObj *note;
+
   g_return_val_if_fail (BIJI_IS_NOTE_OBJ (item), FALSE);
   g_return_val_if_fail (BIJI_IS_NOTEBOOK (notebook), FALSE);
 
-  BijiNoteObj *note = BIJI_NOTE_OBJ (item);
+  note = BIJI_NOTE_OBJ (item);
 
   if (g_hash_table_remove (note->priv->labels, biji_item_get_title (notebook)))
   {
@@ -551,27 +545,6 @@ biji_note_obj_remove_notebook (BijiItem *item, BijiItem *notebook)
   return FALSE;
 }
 
-gboolean
-biji_note_obj_has_tag_prefix (BijiNoteObj *note, gchar *label)
-{
-  gboolean retval = FALSE;
-  GList *tags, *l;
-
-  tags = g_hash_table_get_keys (note->priv->labels);
-
-  for (l = tags; l != NULL; l=l->next)
-  {
-    if (g_str_has_prefix (l->data, label))
-    {
-      retval = TRUE;
-      break;
-    }
-  }
-
-  g_list_free (tags);
-  return retval;
-}
-
 gboolean
 note_obj_is_template (BijiNoteObj *n)
 {
@@ -595,11 +568,11 @@ biji_note_obj_save_note (BijiNoteObj *self)
 gchar *
 biji_note_obj_get_icon_file (BijiNoteObj *note)
 {
-  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (note), NULL);
-
   const gchar *uuid;
   gchar *basename, *filename;
 
+  g_return_val_if_fail (BIJI_IS_NOTE_OBJ (note), NULL);
+
   uuid = BIJI_NOTE_OBJ_GET_CLASS (note)->get_basename (note);
   basename = biji_str_mass_replace (uuid, ".note", ".png", ".txt", ".png", NULL);
 
@@ -793,7 +766,7 @@ biji_note_obj_set_create_date (BijiNoteObj *note, gint64 time)
 /* Webkit */
 
 gchar *
-html_from_plain_text                        (gchar *content)
+html_from_plain_text (const gchar *content)
 {
   gchar *escaped, *retval;
 
@@ -808,12 +781,11 @@ html_from_plain_text                        (gchar *content)
                                 NULL);
 
   retval = g_strconcat ("<html xmlns=\"http://www.w3.org/1999/xhtml\">",
+                        "<head>",
+                        "<link rel='stylesheet' href='Default.css' type='text/css'/>",
+                        "<script language='javascript' src='bijiben.js'></script>"
+                        "</head>",
                         "<body contenteditable='true' id='editable'>",
-                        "<script type='text/javascript'>",
-                        "    window.onload = function () {",
-                        "      document.getElementById('editable').focus();",
-                        "    };",
-                        "</script>",
                         escaped,
                         "</body></html>", NULL);
 
@@ -821,16 +793,57 @@ html_from_plain_text                        (gchar *content)
   return retval;
 }
 
+gboolean
+is_webkit1 (const char *content)
+{
+	if (g_strstr_len (content, -1, "<script type=\"text/javascript\">    window.onload = function () {      document.getElementById('editable').focus();    };</script>") == NULL)
+		return FALSE;
+
+	return TRUE;
+}
+
+gchar *
+convert_webkit1_to_webkit2 (const gchar *content)
+{
+	gchar *stripped = NULL;
+	gchar *webkit2 = NULL;
+
+	stripped = biji_str_mass_replace (content,
+																		"<html xmlns=\"http://www.w3.org/1999/xhtml\"><body contenteditable=\"true\" id=\"editable\">", "",
+																		"<script type=\"text/javascript\">    window.onload = function () {      document.getElementById('editable').focus();    };</script>", "\n",
+																		"<div><br/></div>", "\n",
+																		"<div>", "",
+																		"</div>", "\n",
+																		"<br/>", "\n",
+																		"</body></html>", "",
+																		NULL);
+
+	webkit2 = html_from_plain_text (stripped);
+
+	g_free (stripped);
+
+	return webkit2;
+}
 
 gchar *
 biji_note_obj_get_html (BijiNoteObj *note)
 {
-  return BIJI_NOTE_OBJ_GET_CLASS (note)->get_html (note);
+	gchar *content = BIJI_NOTE_OBJ_GET_CLASS (note)->get_html (note);
+
+	if (is_webkit1 (content))
+		{
+			content = convert_webkit1_to_webkit2 (content);
+			biji_note_obj_set_html (note, content);
+			g_free (content);
+			content = BIJI_NOTE_OBJ_GET_CLASS (note)->get_html (note);
+		}
+
+	return content;
 }
 
 void
 biji_note_obj_set_html (BijiNoteObj *note,
-                        gchar *html)
+                        const gchar *html)
 {
   BIJI_NOTE_OBJ_GET_CLASS (note)->set_html (note, html);
 }
@@ -923,7 +936,7 @@ biji_note_obj_editor_has_selection (BijiNoteObj *note)
   return FALSE;
 }
 
-gchar *
+const gchar *
 biji_note_obj_editor_get_selection (BijiNoteObj *note)
 {
   if (biji_note_obj_is_opened (note))
